summaryrefslogtreecommitdiffstats
path: root/client/components/lists/list.js
diff options
context:
space:
mode:
authorRyan Helsing <ryanhelsing@gmail.com>2017-03-18 18:49:39 -0400
committerRyan Helsing <ryanhelsing@gmail.com>2017-03-18 18:49:39 -0400
commitde10be6a21679ad6ea3a6d97506f84d32cc72d26 (patch)
tree1c34b9656a7df29857ca079cdd105585d9f61538 /client/components/lists/list.js
parentec9498fa627228bd411af6070645fa2ed7cd895d (diff)
downloadwekan-de10be6a21679ad6ea3a6d97506f84d32cc72d26.tar.gz
wekan-de10be6a21679ad6ea3a6d97506f84d32cc72d26.tar.bz2
wekan-de10be6a21679ad6ea3a6d97506f84d32cc72d26.zip
comment only working, naive implementation complete
Diffstat (limited to 'client/components/lists/list.js')
-rw-r--r--client/components/lists/list.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/client/components/lists/list.js b/client/components/lists/list.js
index 187d8ec3..9c191348 100644
--- a/client/components/lists/list.js
+++ b/client/components/lists/list.js
@@ -79,10 +79,10 @@ BlazeComponent.extendComponent({
});
function userIsMember() {
- return Meteor.user() && Meteor.user().isBoardMember();
+ return Meteor.user() && Meteor.user().isBoardMember() && !Meteor.user().isCommentOnly();
}
// Disable drag-dropping if the current user is not a board member
this.autorun(() => {
$cards.sortable('option', 'disabled', !userIsMember());
});
@@ -79,10 +79,10 @@ BlazeComponent.extendComponent({
}
- // Disable drag-dropping if the current user is not a board member
+ // Disable drag-dropping if the current user is not a board member or is comment only
this.autorun(() => {
$cards.sortable('option', 'disabled', !userIsMember());